@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Color.',
                                   class => 'Color',
                                   required => [], # TODO
 }                                 );
@@ -128,28 +128,28 @@ __PACKAGE__->method_documentation({
      'a' => {
      	datatype => 'int',
      	base_name => 'A',
-     	description => '',
+     	description => 'Gets the alpha component value of this System.Drawing.Color structure.            ',
      	format => '',
      	read_only => '',
      		},
      'r' => {
      	datatype => 'int',
      	base_name => 'R',
-     	description => '',
+     	description => 'Gets the red component value of this System.Drawing.Color structure.            ',
      	format => '',
      	read_only => '',
      		},
      'g' => {
      	datatype => 'int',
      	base_name => 'G',
-     	description => '',
+     	description => 'Gets the green component value of this System.Drawing.Color structure.',
      	format => '',
      	read_only => '',
      		},
      'b' => {
      	datatype => 'int',
      	base_name => 'B',
-     	description => '',
+     	description => 'Gets the blue component value of this System.Drawing.Color structure.            ',
      	format => '',
      	read_only => '',
      		},    
