@@ -120,7 +120,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Represents convert worksheet task parameter.',
                                   class => 'ConvertWorksheetTaskParameter',
                                   required => [], # TODO
 }                                 );
@@ -130,70 +130,70 @@ __PACKAGE__->method_documentation({
      'data_source' => {
      	datatype => 'DataSource',
      	base_name => 'DataSource',
-     	description => '',
+     	description => 'Represents data source of task object.',
      	format => '',
      	read_only => '',
      		},
      'workbook' => {
      	datatype => 'FileSource',
      	base_name => 'Workbook',
-     	description => '',
+     	description => 'Represents data source of task object.',
      	format => '',
      	read_only => '',
      		},
      'sheet' => {
      	datatype => 'string',
      	base_name => 'Sheet',
-     	description => '',
+     	description => 'Represents worksheet.',
      	format => '',
      	read_only => '',
      		},
      'target_data_source' => {
      	datatype => 'DataSource',
      	base_name => 'TargetDataSource',
-     	description => '',
+     	description => 'Represents destination data source.',
      	format => '',
      	read_only => '',
      		},
      'target' => {
      	datatype => 'FileSource',
      	base_name => 'Target',
-     	description => '',
+     	description => 'Represents destination data source.',
      	format => '',
      	read_only => '',
      		},
      'format' => {
      	datatype => 'string',
      	base_name => 'Format',
-     	description => '',
+     	description => 'Represents destination data format.',
      	format => '',
      	read_only => '',
      		},
      'area' => {
      	datatype => 'string',
      	base_name => 'Area',
-     	description => '',
+     	description => 'Represents converted data area.',
      	format => '',
      	read_only => '',
      		},
      'page_index' => {
      	datatype => 'int',
      	base_name => 'PageIndex',
-     	description => '',
+     	description => 'Represents converted page index.',
      	format => '',
      	read_only => '',
      		},
      'vertical_resolution' => {
      	datatype => 'int',
      	base_name => 'VerticalResolution',
-     	description => '',
+     	description => 'Represents vertical resolution.',
      	format => '',
      	read_only => '',
      		},
      'horizontal_resolution' => {
      	datatype => 'int',
      	base_name => 'HorizontalResolution',
-     	description => '',
+     	description => 'Represents horizontal resolution.',
      	format => '',
      	read_only => '',
      		},    
