@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -62,8 +62,8 @@ sub new {
 # DeleteDocumentPropertyRequest.name : The workbook name.  ,
 # DeleteDocumentPropertyRequest.propertyName : The property name.  ,
 # DeleteDocumentPropertyRequest.type :   ,
-# DeleteDocumentPropertyRequest.folder : Original workbook folder.  ,
-# DeleteDocumentPropertyRequest.storageName : Storage name.   
+# DeleteDocumentPropertyRequest.folder : The folder where the file is situated.  ,
+# DeleteDocumentPropertyRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -74,7 +74,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'delete_document_property' } = { 
-    	summary => 'Deletes a document property.',
+    	summary => 'Delete an Excel property.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -156,14 +156,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
