@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -70,7 +70,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'get_cells_cloud_service_status' } = { 
-    	summary => 'Aspose.Cells Cloud service health status check(old). ',
+    	summary => 'Aspose.Cells Cloud service health status check.',
         params => $params,
         returns => 'string',
     };
