@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -61,10 +61,11 @@ sub new {
 # Run Operation Request
 # PostClearObjectsRequest.File : File to upload  ,
 # PostClearObjectsRequest.objecttype : chart/comment/picture/shape/listobject/hyperlink/oleobject/pivottable/validation/Background  ,
-# PostClearObjectsRequest.sheetname :   ,
-# PostClearObjectsRequest.outFormat :   ,
-# PostClearObjectsRequest.password :   ,
-# PostClearObjectsRequest.checkExcelRestriction :    
+# PostClearObjectsRequest.sheetname : The worksheet name, specify the scope of the deletion.  ,
+# PostClearObjectsRequest.outFormat : The output data file format.(CSV/XLS/HTML/MHTML/ODS/PDF/XML/TXT/TIFF/XLSB/XLSM/XLSX/XLTM/XLTX/XPS/PNG/JPG/JPEG/GIF/EMF/BMP/MD[Markdown]/Numbers)  ,
+# PostClearObjectsRequest.password : The password needed to open an Excel file.  ,
+# PostClearObjectsRequest.checkExcelRestriction : Whether check restriction of excel file when user modify cells related objects.  ,
+# PostClearObjectsRequest.region : The regional settings for workbook.   
 
 {
     my $params = {
@@ -75,7 +76,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_clear_objects' } = { 
-    	summary => 'Clear excel internal elements for excel files',
+    	summary => 'Clear internal elements in Excel files and generate output files in various formats.',
         params => $params,
         returns => 'FilesResult',
     };
@@ -119,6 +120,10 @@ sub run_http_request {
 
     if(defined $self->check_excel_restriction){
         $query_params->{'checkExcelRestriction'} = $client->to_query_value($self->check_excel_restriction);      
+    }
+
+    if(defined $self->region){
+        $query_params->{'region'} = $client->to_query_value($self->region);      
     } 
     my $_body_data;
  
@@ -157,28 +162,35 @@ __PACKAGE__->method_documentation({
      'sheetname' => {
      	datatype => 'string',
      	base_name => 'sheetname',
-     	description => '',
+     	description => 'The worksheet name, specify the scope of the deletion.',
      	format => '',
      	read_only => '',
      		},
      'out_format' => {
      	datatype => 'string',
      	base_name => 'outFormat',
-     	description => '',
+     	description => 'The output data file format.(CSV/XLS/HTML/MHTML/ODS/PDF/XML/TXT/TIFF/XLSB/XLSM/XLSX/XLTM/XLTX/XPS/PNG/JPG/JPEG/GIF/EMF/BMP/MD[Markdown]/Numbers)',
      	format => '',
      	read_only => '',
      		},
      'password' => {
      	datatype => 'string',
      	base_name => 'password',
-     	description => '',
+     	description => 'The password needed to open an Excel file.',
      	format => '',
      	read_only => '',
      		},
      'check_excel_restriction' => {
      	datatype => 'string',
      	base_name => 'checkExcelRestriction',
-     	description => '',
+     	description => 'Whether check restriction of excel file when user modify cells related objects.',
+     	format => '',
+     	read_only => '',
+     		},
+     'region' => {
+     	datatype => 'string',
+     	base_name => 'region',
+     	description => 'The regional settings for workbook.',
      	format => '',
      	read_only => '',
      		},    
@@ -191,7 +203,8 @@ __PACKAGE__->attribute_map( {
     'sheetname' => 'sheetname',
     'out_format' => 'outFormat',
     'password' => 'password',
-    'check_excel_restriction' => 'checkExcelRestriction' 
+    'check_excel_restriction' => 'checkExcelRestriction',
+    'region' => 'region' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
