@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -60,8 +60,8 @@ sub new {
 
 # Run Operation Request
 # PostProtectRequest.File : File to upload  ,
-# PostProtectRequest.protectWorkbookRequst :   ,
-# PostProtectRequest.password :    
+# PostProtectRequest.protectWorkbookRequest :   ,
+# PostProtectRequest.password : The password needed to open an Excel file.   
 
 {
     my $params = {
@@ -72,7 +72,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_protect' } = { 
-    	summary => 'Protect MS Excel and OpenDocument Spreadsheet by making them password protected.',
+    	summary => 'Excel files encryption.',
         params => $params,
         returns => 'FilesResult',
     };
@@ -112,9 +112,9 @@ sub run_http_request {
     } 
 
     # body params
-    if (defined $self->protect_workbook_requst) {
-        #$_body_data = $self->protect_workbook_requst;
-         $_body_data = JSON->new->convert_blessed->encode( $self->protect_workbook_requst);
+    if (defined $self->protect_workbook_request) {
+        #$_body_data = $self->protect_workbook_request;
+         $_body_data = JSON->new->convert_blessed->encode( $self->protect_workbook_request);
     }
     # authentication setting, if any
     my $auth_settings = [qw()];
@@ -133,9 +133,9 @@ __PACKAGE__->method_documentation({
      	format => '',
      	read_only => '',
      		},
-     'protect_workbook_requst' => {
-     	datatype => 'ProtectWorkbookRequst',
-     	base_name => 'protectWorkbookRequst',
+     'protect_workbook_request' => {
+     	datatype => 'ProtectWorkbookRequest',
+     	base_name => 'protectWorkbookRequest',
      	description => '',
      	format => '',
      	read_only => '',
@@ -143,7 +143,7 @@ __PACKAGE__->method_documentation({
      'password' => {
      	datatype => 'string',
      	base_name => 'password',
-     	description => '',
+     	description => 'The password needed to open an Excel file.',
      	format => '',
      	read_only => '',
      		},    
@@ -152,7 +152,7 @@ __PACKAGE__->method_documentation({
 
 __PACKAGE__->attribute_map( {
     'file' => 'File',
-    'protect_workbook_requst' => 'protectWorkbookRequst',
+    'protect_workbook_request' => 'protectWorkbookRequest',
     'password' => 'password' 
 } );
 
