@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -60,7 +60,7 @@ sub new {
 
 # Run Operation Request
 # PostUnlockRequest.File : File to upload  ,
-# PostUnlockRequest.password :    
+# PostUnlockRequest.password : The password needed to open an Excel file.   
 
 {
     my $params = {
@@ -71,7 +71,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_unlock' } = { 
-    	summary => '',
+    	summary => 'Unlock Excel files.',
         params => $params,
         returns => 'FilesResult',
     };
@@ -130,7 +130,7 @@ __PACKAGE__->method_documentation({
      'password' => {
      	datatype => 'string',
      	base_name => 'password',
-     	description => '',
+     	description => 'The password needed to open an Excel file.',
      	format => '',
      	read_only => '',
      		},    
