@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,11 +59,11 @@ sub new {
 
 
 # Run Operation Request
-# PostWorkbookTextReplaceRequest.name : The workbook name.  ,
+# PostWorkbookTextReplaceRequest.name : The file name.  ,
 # PostWorkbookTextReplaceRequest.oldValue : The old value.  ,
 # PostWorkbookTextReplaceRequest.newValue : The new value.  ,
-# PostWorkbookTextReplaceRequest.folder : Original workbook folder.  ,
-# PostWorkbookTextReplaceRequest.storageName : Storage name.   
+# PostWorkbookTextReplaceRequest.folder : The folder where the file is situated.  ,
+# PostWorkbookTextReplaceRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -74,7 +74,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_workbook_text_replace' } = { 
-    	summary => 'Replaces text in workbook.',
+    	summary => 'Replace text in the workbook.',
         params => $params,
         returns => 'WorkbookReplaceResponse',
     };
@@ -133,7 +133,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -154,14 +154,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
