@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2023 Aspose.Cells Cloud
+Copyright (c) 2024 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -59,11 +59,11 @@ sub new {
 
 
 # Run Operation Request
-# PutChangeVisibilityWorksheetRequest.name : The workbook name.  ,
+# PutChangeVisibilityWorksheetRequest.name : The file name.  ,
 # PutChangeVisibilityWorksheetRequest.sheetName : Worksheet name.  ,
 # PutChangeVisibilityWorksheetRequest.isVisible : New worksheet visibility value.  ,
-# PutChangeVisibilityWorksheetRequest.folder : Original workbook folder.  ,
-# PutChangeVisibilityWorksheetRequest.storageName : Storage name.   
+# PutChangeVisibilityWorksheetRequest.folder : The folder where the file is situated.  ,
+# PutChangeVisibilityWorksheetRequest.storageName : The storage name where the file is situated.   
 
 {
     my $params = {
@@ -74,7 +74,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'put_change_visibility_worksheet' } = { 
-    	summary => 'Changes worksheet visibility.',
+    	summary => 'Change worksheet visibility in the workbook.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -135,7 +135,7 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => 'The workbook name.',
+     	description => 'The file name.',
      	format => '',
      	read_only => '',
      		},
@@ -156,14 +156,14 @@ __PACKAGE__->method_documentation({
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => 'Original workbook folder.',
+     	description => 'The folder where the file is situated.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => 'Storage name.',
+     	description => 'The storage name where the file is situated.',
      	format => '',
      	read_only => '',
      		},    
